psychopy_ext.stats.p_corr — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.stats.p_corr

`psychopy_ext.stats.` `p_corr`(df1, df2=None)

  Computes Pearson correlation and its significance (using a t distribution) on a pandas.DataFrame.

  Ignores null values when computing significance. Based on this Wikipedia entry

  Args: | df1: pandas.DataFrame one dataset df2: pandas.DataFrame another dataset
  Returns: | corr: float correlation between the two datasets t: float an associated t-value p: float one-tailed p-value that the two datasets differ